Args

Struct Args 

pub struct Args {
Show 14 fields pub async_queue_capacity: usize, pub threads: u16, pub block_on_async_queue_full: bool, pub port: u16, pub tcp_port: u16, pub config_hub: String, pub runtime_id: String, pub plugins_path: PathBuf, pub no_config_hub: bool, pub public_host: Option<IpAddr>, pub log_args: GCLoggerArgs, pub ts_host: Option<String>, pub ts_flush_interval_ms: u64, pub ts_buffer_size: usize,
}
Command line arguments for the Gateway

Fields

async_queue_capacity: usize

The size of the async queue

threads: u16

The number of threads to use for the async broker

block_on_async_queue_full: bool

Whether to block when the async queue is full

port: u16

The port to serve the REST API (0 = OS-assigned)

tcp_port: u16

The runtime tcp port (0 = OS-assigned)

config_hub: String

The config hub host address

runtime_id: String

The runtime id used to identify the runtime in the config hub

plugins_path: PathBuf

Plugins path

no_config_hub: bool

Do not attempt to connect to the config hub

public_host: Option<IpAddr>

IP address used by the service hub to reach back to this runtime.

When this is not set, the service hub will attempt to reach the runtime at the IP address from which it receives the announcement.

log_args: GCLoggerArgs

Log information

ts_host: Option<String>

Timeseries ILP host

ts_flush_interval_ms: u64

Timeseries flush interval in ms

ts_buffer_size: usize

Timeseries buffer size (number of datapoint values)